package com.seeyon.apps.govdoc.option.util;

import com.seeyon.apps.govdoc.helper.GovdocHelper;
import com.seeyon.apps.govdoc.manager.GovdocCommentManager;
import com.seeyon.apps.govdoc.manager.GovdocSignetManager;
import com.seeyon.apps.govdoc.option.manager.FormOptionExtendManager;
import com.seeyon.apps.govdoc.option.manager.FormOptionSortManager;
import com.seeyon.apps.govdoc.pishi.po.EdocLeaderPishiNo;
import com.seeyon.apps.govdoc.po.FormOptionExtend;
import com.seeyon.ctp.common.AppContext;
import com.seeyon.ctp.common.ModuleType;
import com.seeyon.ctp.common.SystemEnvironment;
import com.seeyon.ctp.common.affair.manager.AffairManager;
import com.seeyon.ctp.common.authenticate.domain.User;
import com.seeyon.ctp.common.constants.SystemProperties;
import com.seeyon.ctp.common.content.affair.constants.StateEnum;
import com.seeyon.ctp.common.content.affair.constants.SubStateEnum;
import com.seeyon.ctp.common.content.comment.Comment;
import com.seeyon.ctp.common.ctpenumnew.EnumNameEnum;
import com.seeyon.ctp.common.ctpenumnew.manager.EnumManager;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.file.model.CtpLocalFile;
import com.seeyon.ctp.common.i18n.ResourceBundleUtil;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.common.log.CtpLogFactory;
import com.seeyon.ctp.common.po.affair.CtpAffair;
import com.seeyon.ctp.common.po.filemanager.Attachment;
import com.seeyon.ctp.form.api.FormApi4Cap3;
import com.seeyon.ctp.form.bean.FormBean;
import com.seeyon.ctp.form.util.FormUtil;
import com.seeyon.ctp.organization.bo.V3xOrgMember;
import com.seeyon.ctp.organization.manager.OrgManager;
import com.seeyon.ctp.util.Datetimes;
import com.seeyon.ctp.util.FlipInfo;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.util.json.JSONUtil;
import com.seeyon.v3x.edoc.constants.EdocOpinionDisplayEnum;
import com.seeyon.v3x.edoc.domain.EdocOpinion;
import com.seeyon.v3x.edoc.domain.EdocSummary;
import com.seeyon.v3x.edoc.util.Constants;
import com.seeyon.v3x.edoc.webmodel.EdocOpinionBO;
import com.seeyon.v3x.edoc.webmodel.EdocOpinionModel;
import com.seeyon.v3x.edoc.webmodel.FormOpinionConfig;
import com.seeyon.v3x.system.signet.domain.V3xHtmDocumentSignature;
import com.seeyon.v3x.system.signet.domain.V3xSignet;
import com.seeyon.v3x.system.signet.enums.V3xHtmSignatureEnum;
import com.seeyon.v3x.system.signet.manager.SignetManager;
import com.seeyon.v3x.system.signet.manager.V3xHtmDocumentSignatManager;
import com.thoughtworks.xstream.core.util.Base64Encoder;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;
import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;

/* loaded from: EdocOptionDisplayUtil.class */
public class EdocOptionDisplayUtil {
    private static final Log LOGGER = CtpLogFactory.getLog(EdocOptionDisplayUtil.class);

    private static String getAttitude(Integer opinionType, int attitude) {
        String attitudeStr = null;
        String attitudeI18nLabel = "";
        if (attitude > 0) {
            if (EdocOpinion.OpinionType.backOpinion.ordinal() == opinionType.intValue()) {
                attitudeI18nLabel = "stepBack.label";
            } else if (EdocOpinion.OpinionType.stopOpinion.ordinal() == opinionType.intValue()) {
                attitudeI18nLabel = "stepStop.label";
            } else if (EdocOpinion.OpinionType.repealOpinion.ordinal() == opinionType.intValue()) {
                attitudeI18nLabel = "edoc.repeal.2.label";
            } else {
                EnumManager enumManager = (EnumManager) AppContext.getBean("enumManagerNew");
                attitudeI18nLabel = enumManager.getEnumItemLabel(EnumNameEnum.collaboration_attitude, Integer.toString(attitude));
            }
        }
        if (Strings.isNotBlank(attitudeI18nLabel)) {
            attitudeStr = ResourceUtil.getString(attitudeI18nLabel);
        } else if (attitude == Constants.EDOC_ATTITUDE_NULL) {
            attitudeStr = null;
        }
        if (opinionType.intValue() == EdocOpinion.OpinionType.senderOpinion.ordinal()) {
            attitudeStr = null;
        }
        return attitudeStr;
    }

    private static String getOpinionUserName(Long userId, String proxyName, OrgManager orgManager, FormOpinionConfig displayConfig, EdocOpinion edocOpinion, boolean popUserInfo, boolean hasSign) {
        String doUserName = "";
        try {
            V3xOrgMember member = orgManager.getMemberById(userId);
            Long MainAccountId = member.getOrgAccountId();
            doUserName = member.getName();
            String postInfo = edocOpinion.getPostInfo();
            Long currentAccountId = null;
            if (Strings.isNotBlank(postInfo)) {
                String[] postInfos = postInfo.split("\\|");
                if (postInfos.length > 2) {
                    String accountIdStringType = postInfos[0];
                    currentAccountId = Long.valueOf(Long.parseLong(accountIdStringType));
                }
            }
            if (currentAccountId == null) {
                currentAccountId = member.getOrgAccountId();
            }
            if (edocOpinion.isBound() && EdocOpinionDisplayEnum.OpinionShowNameTypeEnum.SIGN.getValue().equals(displayConfig.getShowNameType())) {
                V3xHtmDocumentSignatManager v3xHtmDocumentSignatManager = (V3xHtmDocumentSignatManager) AppContext.getBean("v3xHtmDocumentSignatManager");
                FlipInfo flipInfo = new FlipInfo(-1, -1);
                flipInfo.setNeedTotal(false);
                List<V3xHtmDocumentSignature> signs = v3xHtmDocumentSignatManager.findBySummaryIdAndType(edocOpinion.getEdocId(), V3xHtmSignatureEnum.HTML_SIGNATURE_EDOC_FLOW_INSCRIBE.getKey(), flipInfo);
                List<V3xHtmDocumentSignature> signatureList = new ArrayList<>();
                if (Strings.isNotEmpty(signs)) {
                    for (V3xHtmDocumentSignature sign : signs) {
                        if (sign.getAffairId() != null && edocOpinion.getAffairId() == sign.getAffairId().longValue()) {
                            signatureList.add(sign);
                        }
                    }
                }
                if (Strings.isNotEmpty(signatureList)) {
                    GovdocSignetManager govdocSignetManager = (GovdocSignetManager) AppContext.getBean("govdocSignetManager");
                    List<V3xSignet> signetList = govdocSignetManager.findSignetByMemberId(Long.valueOf(edocOpinion.getCreateUserId()));
                    V3xSignet MainV3xSignet = null;
                    V3xSignet v3xSignet = null;
                    if (signetList != null && !signetList.isEmpty()) {
                        Integer signType = 0;
                        Iterator<V3xSignet> it = signetList.iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                break;
                            }
                            V3xSignet signTemp = it.next();
                            if (signType.equals(signTemp.getMarkType())) {
                                if (currentAccountId == null) {
                                    LOGGER.warn(String.format("未找到%s的单位id，随机取一个签名", userId));
                                    v3xSignet = signTemp;
                                    break;
                                }
                                if (signTemp.getOrgAccountId().longValue() == currentAccountId.longValue()) {
                                    v3xSignet = signTemp;
                                } else if (signTemp.getOrgAccountId().longValue() == MainAccountId.longValue()) {
                                    MainV3xSignet = signTemp;
                                }
                            }
                        }
                    }
                    if (v3xSignet == null && MainV3xSignet != null) {
                        v3xSignet = MainV3xSignet;
                    }
                    if (v3xSignet != null) {
                        String imgStr = "";
                        if (FormUtil.isPhoneLogin() || FormUtil.isH5()) {
                            if (v3xSignet.getMarkBodyByte() != null) {
                                Base64Encoder encoder = new Base64Encoder();
                                String imgStr2 = encoder.encode(v3xSignet.getMarkBodyByte());
                                String imgStr3 = imgStr2.replaceAll("\r\n", "").replace("\\", "").replaceAll("\n", "");
                                if (imgStr3.indexOf("iVBO") == 0) {
                                    imgStr = "data:image/png;base64," + imgStr3;
                                } else if (imgStr3.indexOf("R0lG") == 0) {
                                    imgStr = "data:image/gif;base64," + imgStr3;
                                } else {
                                    imgStr = "data:image/jpeg;base64," + imgStr3;
                                }
                            }
                        } else {
                            imgStr = SystemEnvironment.getContextPath() + "/edocController.do?method=showInscribeSignetPic&id=" + v3xSignet.getId();
                        }
                        doUserName = "<IMG alt=\"" + Strings.toHTML(doUserName) + "\" style=\"pointer-events: none;vertical-align: text-bottom;max-width:100%;\" src=\"" + imgStr + "\" >";
                    } else {
                        LOGGER.warn(String.format("未找到%s的签名！", userId));
                    }
                }
            }
            User user = AppContext.getCurrentUser();
            if (member.getIsAdmin().booleanValue()) {
                doUserName = "<span> " + doUserName + "</span>";
            } else if (popUserInfo && "pc".equals(user.getUserAgentFrom())) {
                doUserName = "<span style='color:#2490f8; display:inline-block;cursor:pointer;' onclick='javascript:showV3XMemberCard(\"" + userId + "\",parent.window)'>" + doUserName + "</span>";
            }
            if (FormUtil.isPhoneLogin() && displayConfig.isHideInscriber() && hasSign) {
                doUserName = "";
            }
            if (!Strings.isBlank(proxyName) && !proxyName.equals(member.getName())) {
                doUserName = doUserName + ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[]{proxyName});
            }
        } catch (Exception e) {
            LOGGER.error("取公文单显示的时候的人名 抛出异常", e);
        }
        return doUserName;
    }

    public static byte[] hex2byte(String str) {
        String str2;
        int len;
        if (str == null || (len = (str2 = str.trim()).length()) == 0 || len % 2 == 1) {
            return null;
        }
        byte[] b = new byte[len / 2];
        for (int i = 0; i < str2.length(); i += 2) {
            try {
                b[i / 2] = (byte) Integer.decode("0X" + str2.substring(i, i + 2)).intValue();
            } catch (Exception e) {
                LOGGER.error("", e);
                return null;
            }
        }
        return b;
    }

    public static Map<String, Object> convertOpinionToString(Map<String, EdocOpinionModel> map, FormOpinionConfig displayConfig, CtpAffair currentAffair, boolean isFromPending, List<V3xHtmDocumentSignature> signatuers, List<Comment> commentList) throws BusinessException {
        return convertOpinionToString(map, displayConfig, signatuers, commentList);
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Code restructure failed: missing block: B:100:0x037b, code lost:
    
        if (r39 != null) goto L97;
     */
    /* JADX WARN: Code restructure failed: missing block: B:101:0x037e, code lost:
    
        r0 = com.seeyon.ctp.util.Datetimes.addSecond(r0.getCreateTime(), -3);
        r0 = com.seeyon.ctp.util.Datetimes.addSecond(r0.getCreateTime(), 3);
        r0 = r0.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:103:0x03a5, code lost:
    
        if (r0.hasNext() == false) goto L225;
     */
    /* JADX WARN: Code restructure failed: missing block: B:104:0x03a8, code lost:
    
        r0 = r0.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:105:0x03c1, code lost:
    
        if (com.seeyon.ctp.util.Datetimes.between(r0.getCreateDate(), r0, r0, false) == false) goto L226;
     */
    /* JADX WARN: Code restructure failed: missing block: B:107:0x03c4, code lost:
    
        r39 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:111:0x03d0, code lost:
    
        if (r39 != null) goto L100;
     */
    /* JADX WARN: Code restructure failed: missing block: B:112:0x03d3, code lost:
    
        r39 = r0.get(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:116:0x03e2, code lost:
    
        if (r39 == null) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:117:0x03e5, code lost:
    
        r0 = r38;
     */
    /* JADX WARN: Code restructure failed: missing block: B:118:0x03ec, code lost:
    
        if (r39.getExtAtt4() != null) goto L105;
     */
    /* JADX WARN: Code restructure failed: missing block: B:119:0x03ef, code lost:
    
        r1 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:121:0x03fc, code lost:
    
        if (r0.equals(r1) == false) goto L109;
     */
    /* JADX WARN: Code restructure failed: missing block: B:122:0x03ff, code lost:
    
        r37 = r39.getExtAtt1I18n();
     */
    /* JADX WARN: Code restructure failed: missing block: B:124:0x040e, code lost:
    
        if (com.seeyon.ctp.util.Strings.isNotBlank(r39.getExtAtt1()) == false) goto L112;
     */
    /* JADX WARN: Code restructure failed: missing block: B:125:0x0411, code lost:
    
        r37 = r39.getExtAtt1I18n();
     */
    /* JADX WARN: Code restructure failed: missing block: B:127:0x0420, code lost:
    
        if (java.util.Objects.nonNull(r39.getCreateDate()) == false) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:128:0x0423, code lost:
    
        r0.setCreateTime(new java.sql.Timestamp(r39.getCreateDate().getTime()));
     */
    /* JADX WARN: Code restructure failed: missing block: B:129:0x03f4, code lost:
    
        r1 = r39.getExtAtt4();
     */
    /* JADX WARN: Code restructure failed: missing block: B:131:0x043c, code lost:
    
        if (com.seeyon.ctp.util.Strings.isBlank(r37) == false) goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:133:0x0444, code lost:
    
        if (com.seeyon.ctp.util.Strings.isBlank(r38) != false) goto L120;
     */
    /* JADX WARN: Code restructure failed: missing block: B:134:0x0447, code lost:
    
        r37 = com.seeyon.ctp.common.i18n.ResourceUtil.getString("collaboration.dealAttitude." + r38);
     */
    /* JADX WARN: Code restructure failed: missing block: B:135:0x0460, code lost:
    
        r0.append(displayOpinionContent(r8, r0, r36, true, r37));
        r41 = null;
     */
    /* JADX WARN: Code restructure failed: missing block: B:136:0x047a, code lost:
    
        if (null == r0.getPolicy()) goto L128;
     */
    /* JADX WARN: Code restructure failed: missing block: B:138:0x0487, code lost:
    
        if (r0.getPolicy().equals("feedback") == false) goto L128;
     */
    /* JADX WARN: Code restructure failed: missing block: B:139:0x048a, code lost:
    
        r0 = r0.getSubOpinionId();
     */
    /* JADX WARN: Code restructure failed: missing block: B:140:0x0493, code lost:
    
        if (r0 == null) goto L129;
     */
    /* JADX WARN: Code restructure failed: missing block: B:141:0x0496, code lost:
    
        r41 = com.seeyon.apps.govdoc.helper.GovdocHelper.getOpinionAttachmentsNotRelationDoc(r0.getSubEdocId().longValue(), r0.longValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:143:0x04b4, code lost:
    
        if (r41 == null) goto L165;
     */
    /* JADX WARN: Code restructure failed: missing block: B:145:0x04bb, code lost:
    
        if (r8.isShowAtt() == false) goto L165;
     */
    /* JADX WARN: Code restructure failed: missing block: B:146:0x04be, code lost:
    
        r0 = new java.lang.StringBuilder();
        r0.append("<br/>");
        r0.append("<div style='clear:both;'>");
        r0 = r41.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:148:0x04e7, code lost:
    
        if (r0.hasNext() == false) goto L227;
     */
    /* JADX WARN: Code restructure failed: missing block: B:149:0x04ea, code lost:
    
        r0 = r0.next();
        r24 = r24 + r0.getFileUrl() + ",";
        r0 = com.seeyon.ctp.util.json.JSONUtil.toJSONString(r0);
        r0 = (java.util.Map) com.seeyon.ctp.util.json.JSONUtil.parseJSONString(r0);
        r0.put("command", "131");
        r0.put("name", r0.getFilename());
        r0 = com.seeyon.ctp.util.json.JSONUtil.toJSONString(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:150:0x0554, code lost:
    
        if (r0.get("icon") == null) goto L139;
     */
    /* JADX WARN: Code restructure failed: missing block: B:151:0x0557, code lost:
    
        r0 = r0.get("icon").toString();
     */
    /* JADX WARN: Code restructure failed: missing block: B:152:0x0568, code lost:
    
        r48 = r0;
        r49 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x0575, code lost:
    
        if ("".equals(r48) != false) goto L145;
     */
    /* JADX WARN: Code restructure failed: missing block: B:155:0x057f, code lost:
    
        if (r48.contains(".") == false) goto L145;
     */
    /* JADX WARN: Code restructure failed: missing block: B:156:0x0582, code lost:
    
        r49 = r48.split("\\.")[0];
     */
    /* JADX WARN: Code restructure failed: missing block: B:158:0x0590, code lost:
    
        if (com.seeyon.ctp.form.util.FormUtil.isPhoneLogin() != false) goto L149;
     */
    /* JADX WARN: Code restructure failed: missing block: B:160:0x0596, code lost:
    
        if (com.seeyon.ctp.form.util.FormUtil.isH5() == false) goto L153;
     */
    /* JADX WARN: Code restructure failed: missing block: B:161:0x05fc, code lost:
    
        r0 = "<span style=\"word-wrap:break-word; word-break:break-all;position:relative;top:-1px;\" class=\"ico16 " + r49 + "_16 margin_r_5\"></span>";
        r51 = com.seeyon.ctp.common.filemanager.manager.Util.AttachmentToHtmlWithShowAllFileName(r0, true, false);
     */
    /* JADX WARN: Code restructure failed: missing block: B:162:0x0628, code lost:
    
        if (org.apache.commons.lang.StringUtils.isNotEmpty(r0.getSecretLevelName()) == false) goto L160;
     */
    /* JADX WARN: Code restructure failed: missing block: B:163:0x062b, code lost:
    
        r52 = com.seeyon.ctp.util.Strings.toHTML(r0.getFilename()) + "(";
        r0 = new java.lang.StringBuffer();
     */
    /* JADX WARN: Code restructure failed: missing block: B:164:0x065e, code lost:
    
        if (r0.getType().intValue() != com.seeyon.ctp.common.filemanager.Constants.ATTACHMENT_TYPE.DOCUMENT.ordinal()) goto L158;
     */
    /* JADX WARN: Code restructure failed: missing block: B:165:0x0661, code lost:
    
        r52 = ">" + com.seeyon.ctp.util.Strings.toHTML(r0.getFilename()) + "<";
        r0.append("><span style=\"color:#FF4141\">[" + r0.getSecretLevelName() + "]</span>").append(com.seeyon.ctp.util.Strings.toHTML(r0.getFilename())).append("<").toString();
     */
    /* JADX WARN: Code restructure failed: missing block: B:166:0x06ef, code lost:
    
        r51 = r51.replace(r52, r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:167:0x06ba, code lost:
    
        r0.append("<span style=\"color:#FF4141\">[" + r0.getSecretLevelName() + "]</span>").append(com.seeyon.ctp.util.Strings.toHTML(r0.getFilename())).append("(").toString();
     */
    /* JADX WARN: Code restructure failed: missing block: B:168:0x06fd, code lost:
    
        r0 = r51.indexOf("<img");
        r0 = r51.substring(0, r0) + r0 + r51.substring(r51.indexOf("<", r0 + 4), r51.length());
     */
    /* JADX WARN: Code restructure failed: missing block: B:170:0x073a, code lost:
    
        r45 = r0;
        r0.append(r45);
        r0.append(r45);
     */
    /* JADX WARN: Code restructure failed: missing block: B:171:0x0599, code lost:
    
        r50 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:172:0x05a2, code lost:
    
        if (com.seeyon.ctp.util.Strings.isNotBlank(r49) == false) goto L152;
     */
    /* JADX WARN: Code restructure failed: missing block: B:173:0x05a5, code lost:
    
        r50 = getIconClass(r49);
     */
    /* JADX WARN: Code restructure failed: missing block: B:174:0x05ac, code lost:
    
        r0 = "<i class='attachment-icon " + r50 + "'></i>";
        r0 = "<div style='display:block'>" + r0 + "<a class='document-content allow-click-attachment' style='text-decoration:underline;margin-left:10px;font-size:12px;color:#005599' see-att-data = '" + r0 + "'>" + r0.getFilename() + "</a></div>";
     */
    /* JADX WARN: Code restructure failed: missing block: B:176:0x0566, code lost:
    
        r0 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:178:0x074d, code lost:
    
        r0.append("</div>");
     */
    /* JADX WARN: Code restructure failed: missing block: B:179:0x075c, code lost:
    
        if ("senderOpinion".equals(r0) == false) goto L165;
     */
    /* JADX WARN: Code restructure failed: missing block: B:180:0x075f, code lost:
    
        r0.put(r0.getId(), r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:182:0x0770, code lost:
    
        if (r33 == false) goto L170;
     */
    /* JADX WARN: Code restructure failed: missing block: B:183:0x0773, code lost:
    
        r0 = r0.get(java.lang.Long.valueOf(r0.getAffairId()));
        r0 = r22.get(java.lang.Long.valueOf(r0.getAffairId()));
     */
    /* JADX WARN: Code restructure failed: missing block: B:184:0x079d, code lost:
    
        if (r0 == null) goto L170;
     */
    /* JADX WARN: Code restructure failed: missing block: B:185:0x07a0, code lost:
    
        r0.append(displayEditAndDelButton(r0.getId(), r0, r0));
        r0.append("<br/>");
     */
    /* JADX WARN: Code restructure failed: missing block: B:187:0x07c1, code lost:
    
        if ("senderOpinion".equals(r0) == false) goto L205;
     */
    /* JADX WARN: Code restructure failed: missing block: B:190:0x07d3, code lost:
    
        if (r41 == null) goto L177;
     */
    /* JADX WARN: Code restructure failed: missing block: B:192:0x07da, code lost:
    
        if (r8.isShowAtt() != false) goto L178;
     */
    /* JADX WARN: Code restructure failed: missing block: B:193:0x07e5, code lost:
    
        r0.put(r0, r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:196:0x07dd, code lost:
    
        r0.append("<br/>");
     */
    /* JADX WARN: Code restructure failed: missing block: B:198:0x07c4, code lost:
    
        r0.add(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:200:0x04ab, code lost:
    
        r41 = r0.getOpinionAttachments();
     */
    /* JADX WARN: Code restructure failed: missing block: B:87:0x0306, code lost:
    
        r39 = null;
        r0 = r0.get(java.lang.Long.valueOf(r0.getAffairId()));
     */
    /* JADX WARN: Code restructure failed: missing block: B:88:0x0322, code lost:
    
        if (com.seeyon.ctp.util.Strings.isNotEmpty(r0) == false) goto L100;
     */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x032d, code lost:
    
        if (r0.size() != 1) goto L81;
     */
    /* JADX WARN: Code restructure failed: missing block: B:91:0x0330, code lost:
    
        r39 = r0.get(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x0340, code lost:
    
        r0 = r0.iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x0350, code lost:
    
        if (r0.hasNext() == false) goto L221;
     */
    /* JADX WARN: Code restructure failed: missing block: B:95:0x0353, code lost:
    
        r0 = r0.next();
     */
    /* JADX WARN: Code restructure failed: missing block: B:96:0x036c, code lost:
    
        if (r0.getCreateDate().equals(r0.getCreateTime()) == false) goto L223;
     */
    /* JADX WARN: Code restructure failed: missing block: B:98:0x036f, code lost:
    
        r39 = r0;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.util.Map<java.lang.String, java.lang.Object> convertOpinionToString(java.util.Map<java.lang.String, com.seeyon.v3x.edoc.webmodel.EdocOpinionModel> r7, com.seeyon.v3x.edoc.webmodel.FormOpinionConfig r8, java.util.List<com.seeyon.v3x.system.signet.domain.V3xHtmDocumentSignature> r9, java.util.List<com.seeyon.ctp.common.content.comment.Comment> r10) throws com.seeyon.ctp.common.exceptions.BusinessException {
        /*
            Method dump skipped, instructions count: 2198
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.convertOpinionToString(java.util.Map, com.seeyon.v3x.edoc.webmodel.FormOpinionConfig, java.util.List, java.util.List):java.util.Map");
    }

    private static String displayEditAndDelButton(Long commentId, EdocOpinion opinion, EdocLeaderPishiNo edocLeaderPishiNo) {
        String edocLeaderPishiStr = "";
        if (edocLeaderPishiNo != null) {
            StringBuilder sb = new StringBuilder();
            String pishiName = edocLeaderPishiNo.getPishiName();
            Integer pishiNo = edocLeaderPishiNo.getPishiNo();
            String pishiYear = edocLeaderPishiNo.getPishiYear();
            Date proxyDate = edocLeaderPishiNo.getProxyDate();
            String proxyDateShow = Datetimes.formatDate(edocLeaderPishiNo.getProxyDate());
            sb.append("hasPishi=\"true\"");
            sb.append("pishiName=\"" + pishiName + "\"");
            sb.append("pishiNo=\"" + pishiNo + "\"");
            sb.append("pishiYear=\"" + pishiYear + "\"");
            sb.append("proxyDate=\"" + proxyDate + "\"");
            sb.append("proxyDateShow=\"" + proxyDateShow + "\"");
            edocLeaderPishiStr = Strings.toText(sb.toString());
        }
        String content = Strings.toHTML(opinion.getContent());
        String opinionId = opinion.getId().toString();
        Long affairId = Long.valueOf(opinion.getAffairId());
        return "<a " + edocLeaderPishiStr + " class=\"formPrintHide\"  onclick=\"openEditWindow(this)\" affairId=\"" + affairId + "\" content=\"" + content + "\" commentId=\"" + commentId + "\"  opinionId=\"" + opinionId + "\"  >" + ResourceUtil.getString("common.operate.edit") + "</a>&nbsp&nbsp<a   class=\"formPrintHide\"  onclick=\"delComment('" + commentId + "')\" >" + ResourceUtil.getString("common.toolbar.delete.label") + "</a>";
    }

    private static String replaceStr2Blank(String src, String defualt) {
        StringBuilder ret = new StringBuilder();
        if (Strings.isBlank(src) && defualt != null) {
            ret.append(defualt);
        } else {
            for (int i = 0; i < src.length(); i++) {
                char c = src.charAt(i);
                if (c > 0 && c < 255) {
                    ret.append(ResourceUtil.getString("govdoc.space"));
                } else {
                    ret.append(ResourceUtil.getString("govdoc.space.quan"));
                }
            }
        }
        return ret.toString();
    }

    private static String displayOpinionContent(FormOpinionConfig displayConfig, EdocOpinion opinion, boolean hasSignature, boolean popUserInfo, String attitude) {
        OrgManager orgManager = (OrgManager) AppContext.getBean("orgManager");
        StringBuilder sb = new StringBuilder();
        String attribute = attitude;
        String userName = getOpinionUserName(Long.valueOf(opinion.getCreateUserId()), opinion.getProxyName(), orgManager, displayConfig, opinion, popUserInfo, hasSignature);
        String content = opinion.getContent();
        String divId = String.valueOf(opinion.getAffairId());
        if (opinion.getOpinionType().intValue() == EdocOpinion.OpinionType.provisionalOpinoin.ordinal()) {
            divId = divId + "_zc";
        }
        sb.append("<div id='" + divId + "' class='edocOpinion' style='clear:both;'>");
        sb.append("</div>");
        boolean newLine = displayConfig.isInscriberNewLine();
        if (newLine) {
            sb.append("<span>");
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getAttitude())) {
            attribute = "";
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getComment())) {
            content = "";
        }
        if (Strings.isNotBlank(attribute) && attribute != null && null != opinion.getPolicy() && !opinion.getPolicy().equals("report")) {
            String attrStr = "【" + attribute + "】";
            sb.append(attrStr);
        }
        sb.append(Strings.toHTML(content));
        if (newLine) {
            sb.append("</span><br/>");
        }
        boolean alignRight = FormOpinionConfig.checkBoolean(displayConfig.getInscriberRight());
        if (newLine) {
            if (alignRight) {
                sb.append("<span style='text-align: right;width: 100%;display: inline-block; font-size: inherit;font-weight: inherit;font-style: inherit;'>");
            } else {
                sb.append("<span>");
                sb.append("");
            }
        } else if (Strings.isNotBlank(content) && (displayConfig.isShowDept() || displayConfig.isShowUnit())) {
            sb.append("&ensp;&ensp;");
        }
        boolean isDisplay = true;
        if (displayConfig.isHideInscriber()) {
            AffairManager affairManager = (AffairManager) AppContext.getBean("affairManager");
            try {
                CtpAffair affair = affairManager.get(Long.valueOf(opinion.getAffairId()));
                if (affair != null) {
                    if (affair.getSubState().intValue() == SubStateEnum.col_done_stepStop.key()) {
                        isDisplay = false;
                    }
                }
            } catch (BusinessException e) {
                LOGGER.error("获取affair错误", e);
            }
        }
        if (displayConfig.isShowUnit() && ((!displayConfig.isHideInscriber() || !hasSignature) && isDisplay)) {
            if (userName.indexOf("IMG") != -1 || newLine) {
                sb.append(opinion.getAccountName());
            } else {
                sb.append("&ensp;").append(opinion.getAccountName());
            }
        }
        if (displayConfig.isShowDept() && ((!displayConfig.isHideInscriber() || !hasSignature) && isDisplay)) {
            if ((userName.indexOf("IMG") != -1 || newLine) && !displayConfig.isShowUnit()) {
                sb.append(opinion.getDepartmentName());
            } else {
                sb.append("&ensp;").append(opinion.getDepartmentName());
            }
        }
        if (displayConfig.isShowName() && ((!displayConfig.isHideInscriber() || !hasSignature) && isDisplay)) {
            sb.append("&ensp;").append(userName);
        }
        String dateStr = "";
        if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATETIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format"));
            } else {
                dateStr = Datetimes.formatDatetimeWithoutSecond(opinion.getCreateTime());
            }
        } else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATE.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current2 = opinion.getCreateTime();
                dateStr = Datetimes.format(current2, ResourceUtil.getString("govdoc.date.format1"));
            } else {
                dateStr = Datetimes.formatDate(opinion.getCreateTime());
            }
        } else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.TIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current3 = opinion.getCreateTime();
                dateStr = Datetimes.format(current3, ResourceUtil.getString("govdoc.date.format3"));
            } else {
                dateStr = Datetimes.format(opinion.getCreateTime(), " HH:mm");
            }
        }
        boolean dateNewLine = false;
        if (Strings.isNotBlank(dateStr)) {
            dateNewLine = FormOpinionConfig.checkBoolean(displayConfig.getDateNewLine());
            if (dateNewLine) {
                String styleText = "";
                if (alignRight) {
                    styleText = "text-align: right;width: 100%;display: inline-block;font-size: inherit;font-weight: inherit;font-style: inherit;";
                }
                if (newLine) {
                    sb.append("</span>");
                    sb.append("<br/>");
                    sb.append("<span style='color:black;display:block;" + styleText + "'>");
                    if (!alignRight) {
                        sb.append("");
                    }
                    sb.append(dateStr);
                } else {
                    sb.append("<br/>");
                    sb.append("<span style='display:block;" + styleText + "'>");
                    sb.append(dateStr);
                    sb.append("</span>");
                }
            } else {
                sb.append("&ensp;").append(dateStr);
            }
        }
        if (newLine) {
            if (alignRight) {
                sb.append("</span>");
            } else {
                sb.append("</span>");
            }
        }
        if (dateNewLine) {
            sb.append("<br/>");
        }
        return sb.toString().replaceAll("&nbsp;", "&ensp;");
    }

    private static V3xOrgMember getMember(Long id, OrgManager orgManager) {
        V3xOrgMember member = new V3xOrgMember();
        try {
            member = orgManager.getMemberById(id);
        } catch (BusinessException e) {
            LOGGER.error("", e);
        }
        return member;
    }

    public static String optionToJs(Map<String, Object> hs) {
        StringBuilder opinionsJs = new StringBuilder();
        opinionsJs.append("var opinions=[");
        boolean isFirst = true;
        for (String key : hs.keySet()) {
            if (!"senderOpinionList".equals(key) && !"senderOpinionAttStr".equals(key) && !"commentAttachments".equals(key)) {
                if (isFirst) {
                    isFirst = false;
                } else {
                    opinionsJs.append(",");
                }
                String szTemp = hs.get(key).toString();
                opinionsJs.append("[\"").append(key).append("\",\"").append(Strings.escapeJavascript(szTemp)).append("\"]");
            }
        }
        opinionsJs.append("];");
        opinionsJs.append("\r\n");
        String sendOpinionStr = "";
        Object sendOpinionObj = hs.get("senderOpinionList");
        Object opinionsAttachmentList = hs.get("commentAttachments");
        if (opinionsAttachmentList != null) {
            opinionsJs.append("var opinionsAttachmentList=" + JSONUtil.toJSONString(opinionsAttachmentList) + ";");
        }
        if (sendOpinionObj != null) {
            sendOpinionStr = sendOpinionObj.toString();
        }
        if ("[]".equals(sendOpinionStr)) {
            sendOpinionStr = "";
        }
        opinionsJs.append("var sendOpinionStr=\"" + sendOpinionStr + "\";");
        opinionsJs.append("var edocDetailURL=\"" + SystemEnvironment.getContextPath() + "/edocController.do\";");
        return opinionsJs.toString();
    }

    public static String getEdocOpinionPolicy(Map<String, EdocOpinionModel> map) {
        Set set;
        String policy = null;
        if (map != null && !map.isEmpty() && (set = map.entrySet()) != null && !set.isEmpty()) {
            for (Map.Entry<String, EdocOpinionModel> entry : set) {
                if (entry != null) {
                    policy = entry.getKey().toString();
                }
            }
        }
        return policy;
    }

    public static List<EdocOpinionBO> sortEdocOpinion(List<EdocOpinion> opinions) {
        List<EdocOpinionBO> opinionBOs = new ArrayList<>();
        if (opinions != null) {
            for (int i = 0; i < opinions.size(); i++) {
                try {
                    EdocOpinionBO edocOpinionBO = new EdocOpinionBO();
                    BeanUtils.copyProperties(edocOpinionBO, opinions.get(i));
                    opinionBOs.add(edocOpinionBO);
                } catch (Exception e) {
                }
            }
        }
        return opinionBOs;
    }

    public static String getAffairReturnState(Map<String, EdocOpinionModel> map, String policy, CtpAffair currentAffair) throws BusinessException {
        List<EdocOpinion> opinions = null;
        EdocOpinionModel edocOpinionModel = null;
        if (map != null) {
            edocOpinionModel = map.get(policy);
        }
        if (edocOpinionModel != null) {
            opinions = edocOpinionModel.getOpinions();
        }
        return getAffairReturnState(opinions, currentAffair);
    }

    public static String getAffairReturnState(List<EdocOpinion> opinions, CtpAffair currentAffair) throws BusinessException {
        List<EdocOpinionBO> opinionBOs = sortEdocOpinion(opinions);
        AffairManager affairManager = (AffairManager) AppContext.getBean("affairManager");
        String affairState = "";
        if (opinionBOs != null) {
            CtpAffair affair = null;
            int count = opinionBOs.size();
            long currentUserId = AppContext.getCurrentUser().getId().longValue();
            int i = count - 1;
            while (true) {
                if (i < 0) {
                    break;
                }
                EdocOpinionBO edocOpinion = opinionBOs.get(i);
                CtpAffair affair1 = affairManager.get(Long.valueOf(edocOpinion.getAffairId()));
                if (affair1 != null) {
                    boolean isCurrentAffair = (affair1 == null || affair1.getActivityId() == null || currentAffair.getActivityId() == null || !affair1.getActivityId().equals(currentAffair.getActivityId()) || affair1.getMemberId().longValue() != currentUserId) ? false : true;
                    boolean isCurrentAffairState = affair1.getState().intValue() == StateEnum.col_pending.key() && (affair1.getSubState().intValue() == SubStateEnum.col_pending_ZCDB.key() || affair1.getSubState().intValue() == SubStateEnum.col_pending_read.key());
                    if (isCurrentAffair && !isCurrentAffairState) {
                        affair = affair1;
                        break;
                    }
                }
                i--;
            }
            if (affair != null) {
                affairState = String.valueOf(affair.getState());
            }
        }
        return affairState;
    }

    private static String subLargerGuanlanWendang(String str) {
        int begin = str.indexOf("style='font-size:12px'>");
        int end = str.indexOf("</a>");
        if (begin != -1 || end != -1) {
            String wname = str.substring(begin, end).replace("style='font-size:12px'>", "");
            StringBuilder sb = new StringBuilder();
            if (wname.length() < 30) {
                return str;
            }
            sb.append(str.substring(0, begin));
            sb.append("style='font-size:12px'>");
            String wname2 = wname.replace("&nbsp;", " ");
            if (wname2.length() > 30) {
                wname2 = wname2.substring(0, 30);
            }
            sb.append(wname2);
            sb.append("......");
            sb.append(str.substring(end));
            return sb.toString();
        }
        return str;
    }

    private static String getOpinionImgUserNameForGZZB(Long userId, String proxyName, OrgManager orgManager) {
        String doUserName = "";
        try {
            V3xOrgMember member = orgManager.getMemberById(userId);
            String doUserName2 = member.getName();
            if (member.getIsAdmin().booleanValue()) {
                doUserName = "";
            } else {
                SignetManager signetManager = (SignetManager) AppContext.getBean("signetManager");
                List<V3xSignet> signets = signetManager.findSignetByMemberId(userId);
                V3xSignet ssi = null;
                if (signets != null && signets.size() > 0) {
                    int i = 0;
                    while (true) {
                        if (i >= signets.size()) {
                            break;
                        }
                        if (!signets.get(i).getMarkType().equals(0)) {
                            i++;
                        } else {
                            ssi = signets.get(i);
                            break;
                        }
                    }
                }
                String namePath = SystemEnvironment.getContextPath() + "/apps_res/edoc/images/signets/";
                if (ssi != null) {
                    byte[] b = ssi.getMarkBodyByte();
                    String path = ((SystemProperties.getInstance().getProperty("A8.base.folder") + "/") + "../ApacheJetspeed/webapps") + namePath;
                    CtpLocalFile file = new CtpLocalFile(path);
                    if (!file.exists()) {
                        file.mkdirs();
                    }
                    writeFile(path + userId + ssi.getImgType(), b);
                    String spath = namePath + userId + ssi.getImgType() + "?r=" + System.currentTimeMillis();
                    doUserName = "<img name='signimg' src=" + spath + " class='color_blue'  onclick='javascript:showV3XMemberCard(\"" + userId + "\")'></img>";
                } else {
                    doUserName = "<span class='color_blue' onclick='javascript:showV3XMemberCard(\"" + userId + "\")'>" + doUserName2 + "</span>";
                }
            }
            if (!Strings.isBlank(proxyName)) {
                doUserName = doUserName + ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[]{proxyName});
            }
        } catch (Exception e) {
            LOGGER.error(e.getMessage(), e);
        }
        return "<br>&nbsp;&nbsp;&nbsp;&nbsp;" + doUserName;
    }

    private static String getIconClass(String type) {
        if ("txt".equals(type)) {
            return "see-icon-v5-form-ic-txt-fill";
        }
        if ("jpg".equals(type) || "png".equals(type) || "icon".equals(type) || "gif".equals(type)) {
            return "see-icon-v5-form-ic-image-fill";
        }
        if ("doc".equals(type) || "docx".equals(type)) {
            return "see-icon-v5-form-ic-doc-fill";
        }
        if ("xls".equals(type) || "xlsx".equals(type)) {
            return "see-icon-v5-form-ic-xls-fill";
        }
        if ("ppt".equals(type) || "pptx".equals(type)) {
            return "see-icon-v5-form-ic-ppt-fill";
        }
        if ("wps".equals(type)) {
            return "see-icon-v5-form-ic-wps-fill";
        }
        if ("vsd".equals(type)) {
            return "see-icon-v5-form-ic-vsd-fill";
        }
        if ("pdf".equals(type)) {
            return "see-icon-v5-form-ic-pdf-fill";
        }
        if ("et".equals(type)) {
            return "see-icon-v5-form-ic-et-fill";
        }
        if ("htm".equals(type) || "html".equals(type) || "sht".equals(type) || "shtm".equals(type) || "shtml".equals(type) || "asp".equals(type) || "aspx".equals(type) || "php".equals(type) || "jsp".equals(type)) {
            return "see-icon-v5-form-ic-html-fill";
        }
        if ("mp3".equals(type)) {
            return "see-icon-v5-form-ic-mp3-fill";
        }
        if ("avi".equals(type) || "mp4".equals(type) || "wmv".equals(type) || "rm".equals(type) || "rmvb".equals(type) || "mpg".equals(type) || "mkv".equals(type) || "flv".equals(type)) {
            return "see-icon-v5-form-ic-mp4-fill";
        }
        if ("wma".equals(type) || "wav".equals(type) || "amr".equals(type) || "ACT".equals(type) || "ava".equals(type)) {
            return "see-icon-v5-form-ic-voice-fill";
        }
        if ("zip".equals(type) || "rar".equals(type) || "jar".equals(type) || "tar".equals(type) || "7z".equals(type)) {
            return "see-icon-v5-form-ic-zip-fill";
        }
        if ("collaboration".equals(type)) {
            return "see-icon-v5-form-ic-col-fill";
        }
        if ("edoc".equals(type)) {
            return "see-icon-v5-form-ic-offdoc-fill";
        }
        if ("km".equals(type)) {
            return "see-icon-v5-form-relation-doc";
        }
        if ("exe".equals(type)) {
            return "cmp-icon-document exe";
        }
        if ("ofd".equals(type)) {
            return "cmp-icon-document ofd";
        }
        return "see-icon-v5-form-ic-unknown-fill";
    }

    /* JADX WARN: Removed duplicated region for block: B:36:0x00c8 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0093 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static void writeFile(java.lang.String r4, byte[] r5) {
        /*
            com.seeyon.ctp.common.file.model.CtpLocalFile r0 = new com.seeyon.ctp.common.file.model.CtpLocalFile
            r1 = r0
            r2 = r4
            r1.<init>(r2)
            r6 = r0
            r0 = 0
            r7 = r0
            r0 = 0
            r8 = r0
            r0 = r6
            boolean r0 = r0.exists()     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            if (r0 == 0) goto L1a
            r0 = r6
            boolean r0 = r0.delete()     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
        L1a:
            r0 = r6
            boolean r0 = r0.createNewFile()     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            java.io.FileOutputStream r0 = new java.io.FileOutputStream     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            r1 = r0
            r2 = r6
            r1.<init>(r2)     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            r8 = r0
            java.io.BufferedOutputStream r0 = new java.io.BufferedOutputStream     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            r1 = r0
            r2 = r8
            r1.<init>(r2)     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            r7 = r0
            r0 = r7
            r1 = r5
            r0.write(r1)     // Catch: java.io.IOException -> L6b java.lang.Throwable -> Laa
            r0 = r7
            if (r0 == 0) goto L40
            r0 = r7
            r0.close()     // Catch: java.io.IOException -> L43
        L40:
            goto L4f
        L43:
            r9 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r9
            r0.error(r1)
        L4f:
            r0 = r8
            if (r0 == 0) goto L59
            r0 = r8
            r0.close()     // Catch: java.io.IOException -> L5c
        L59:
            goto Ldf
        L5c:
            r9 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r9
            r0.error(r1)
            goto Ldf
        L6b:
            r9 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER     // Catch: java.lang.Throwable -> Laa
            r1 = r9
            r0.error(r1)     // Catch: java.lang.Throwable -> Laa
            r0 = r7
            if (r0 == 0) goto L7f
            r0 = r7
            r0.close()     // Catch: java.io.IOException -> L82
        L7f:
            goto L8e
        L82:
            r9 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r9
            r0.error(r1)
        L8e:
            r0 = r8
            if (r0 == 0) goto L98
            r0 = r8
            r0.close()     // Catch: java.io.IOException -> L9b
        L98:
            goto Ldf
        L9b:
            r9 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r9
            r0.error(r1)
            goto Ldf
        Laa:
            r10 = move-exception
            r0 = r7
            if (r0 == 0) goto Lb4
            r0 = r7
            r0.close()     // Catch: java.io.IOException -> Lb7
        Lb4:
            goto Lc3
        Lb7:
            r11 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r11
            r0.error(r1)
        Lc3:
            r0 = r8
            if (r0 == 0) goto Lcd
            r0 = r8
            r0.close()     // Catch: java.io.IOException -> Ld0
        Lcd:
            goto Ldc
        Ld0:
            r11 = move-exception
            org.apache.commons.logging.Log r0 = com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.LOGGER
            r1 = r11
            r0.error(r1)
        Ldc:
            r0 = r10
            throw r0
        Ldf:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.seeyon.apps.govdoc.option.util.EdocOptionDisplayUtil.writeFile(java.lang.String, byte[]):void");
    }

    public static String getOpinionUserNameForM3(V3xOrgMember member, FormOpinionConfig displayConfig, EdocOpinion edocOpinion, boolean hasHandWriteSignature, List<V3xHtmDocumentSignature> edocOpinionSigns, String proxyName) {
        String doUserName = "";
        try {
            doUserName = member.getName();
            String postInfo = edocOpinion.getPostInfo();
            Long accountId = null;
            if (Strings.isNotBlank(postInfo)) {
                String[] postInfos = postInfo.split("\\|");
                if (postInfos.length > 2) {
                    String accountIdStringType = postInfos[0];
                    accountId = Long.valueOf(Long.parseLong(accountIdStringType));
                }
            }
            if (accountId == null) {
                accountId = member.getOrgAccountId();
            }
            if (edocOpinion.isBound() && EdocOpinionDisplayEnum.OpinionShowNameTypeEnum.SIGN.getValue().equals(displayConfig.getShowNameType())) {
                List<V3xHtmDocumentSignature> signatureList = new ArrayList<>();
                if (Strings.isNotEmpty(edocOpinionSigns)) {
                    for (V3xHtmDocumentSignature sign : edocOpinionSigns) {
                        if (sign.getAffairId() != null && Strings.equals(Long.valueOf(edocOpinion.getAffairId()), sign.getAffairId())) {
                            signatureList.add(sign);
                        }
                    }
                }
                if (Strings.isNotEmpty(signatureList)) {
                    GovdocSignetManager govdocSignetManager = (GovdocSignetManager) AppContext.getBean("govdocSignetManager");
                    List<V3xSignet> signetList = govdocSignetManager.findSignetByMemberId(Long.valueOf(edocOpinion.getCreateUserId()));
                    V3xSignet v3xSignet = null;
                    if (signetList != null && !signetList.isEmpty()) {
                        Integer signType = new Integer(0);
                        Iterator<V3xSignet> it = signetList.iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                break;
                            }
                            V3xSignet signTemp = it.next();
                            if (signType.equals(signTemp.getMarkType())) {
                                if (accountId == null) {
                                    v3xSignet = signTemp;
                                    break;
                                }
                                if (signTemp.getOrgAccountId().longValue() == accountId.longValue()) {
                                    v3xSignet = signTemp;
                                    break;
                                }
                            }
                        }
                    }
                    if (v3xSignet != null) {
                        doUserName = "id=" + v3xSignet.getId();
                    }
                }
            }
            if (member.getIsAdmin().booleanValue()) {
                doUserName = "";
            }
            if (displayConfig.isHideInscriber() && hasHandWriteSignature) {
                doUserName = "";
            }
            if (!Strings.isBlank(proxyName) && !doUserName.startsWith("id=")) {
                doUserName = doUserName + ResourceBundleUtil.getString("com.seeyon.v3x.edoc.resources.i18n.EdocResource", "edoc.opinion.proxy", new Object[]{proxyName});
            }
        } catch (Exception e) {
            LOGGER.error("取公文单显示的时候的人名 抛出异常", e);
        }
        return doUserName;
    }

    public static List<Object> getGovdocOpinionsForM3TaoHong(EdocSummary summary) throws BusinessException {
        V3xHtmDocumentSignature handWrite;
        FormApi4Cap3 formApi4Cap3 = (FormApi4Cap3) AppContext.getBean("formApi4Cap3");
        FormOptionExtendManager formOptionExtendManager = (FormOptionExtendManager) AppContext.getBean("formOptionExtendManager");
        FormOptionSortManager formOptionSortManager = (FormOptionSortManager) AppContext.getBean("formOptionSortManager");
        V3xHtmDocumentSignatManager v3xHtmDocumentSignatManager = (V3xHtmDocumentSignatManager) AppContext.getBean("v3xHtmDocumentSignatManager");
        GovdocCommentManager govdocCommentManager = (GovdocCommentManager) AppContext.getBean("govdocCommentManager");
        OrgManager orgManager = (OrgManager) AppContext.getBean("orgManager");
        AffairManager affairManager = (AffairManager) AppContext.getBean("affairManager");
        FormOpinionConfig displayConfig = getFormOpinionConfig(summary, formOptionExtendManager);
        Map<String, EdocOpinionModel> filedNameMapOpinions = formOptionSortManager.getGovdocOpinion(summary.getFormAppid().longValue(), summary, displayConfig);
        List<V3xHtmDocumentSignature> handWrites = v3xHtmDocumentSignatManager.findBySummaryIdAndType(summary.getId(), V3xHtmSignatureEnum.HTML_SIGNATURE_DOCUMENT.getKey());
        Map<Long, V3xHtmDocumentSignature> affairIdMapHandWriteSign = null;
        if (Strings.isNotEmpty(handWrites)) {
            affairIdMapHandWriteSign = (Map) handWrites.stream().collect(Collectors.toMap((v0) -> {
                return v0.getAffairId();
            }, signature -> {
                return signature;
            }, (a, b) -> {
                return b;
            }));
        }
        List<V3xHtmDocumentSignature> edocOpinionSigns = v3xHtmDocumentSignatManager.findBySummaryIdAndType(summary.getId(), V3xHtmSignatureEnum.HTML_SIGNATURE_EDOC_FLOW_INSCRIBE.getKey());
        int backOpinionType = displayConfig.getBackOpinionType();
        Map<Long, List<Comment>> commentMap = new HashMap<>();
        List<Comment> commentList = govdocCommentManager.getCommentList(ModuleType.edoc, summary.getId());
        if (Strings.isNotEmpty(commentList)) {
            commentMap = (Map) commentList.stream().filter(item -> {
                return (backOpinionType == 1 && "common.toolbar.stepBack.label".equals(item.getExtAtt3())) ? false : true;
            }).collect(Collectors.groupingBy((v0) -> {
                return v0.getAffairId();
            }));
        }
        boolean showZcdb = !FormOpinionConfig.checkBoolean(displayConfig.getZcdbOptionType());
        FormBean form = formApi4Cap3.getForm(summary.getFormAppid().longValue());
        Map<String, String> fieldNameMapElement = (Map) form.getAllFieldBeans().stream().filter(fieldBean -> {
            return Strings.isNotBlank(fieldBean.getMappingField());
        }).collect(Collectors.toMap((v0) -> {
            return v0.getName();
        }, (v0) -> {
            return v0.getMappingField();
        }, (a2, b2) -> {
            return b2;
        }));
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        for (Map.Entry<String, EdocOpinionModel> entry : filedNameMapOpinions.entrySet()) {
            String fieldName = entry.getKey();
            EdocOpinionModel model = entry.getValue();
            List<EdocOpinion> edocOpinionList = model.getOpinions();
            ArrayList arrayList3 = new ArrayList();
            arrayList3.add(fieldNameMapElement.get(fieldName));
            for (EdocOpinion opinion : edocOpinionList) {
                if (!Strings.equals(Integer.valueOf(EdocOpinion.OpinionType.provisionalOpinoin.ordinal()), opinion.getOpinionType()) || showZcdb) {
                    if (!Strings.equals(Integer.valueOf(EdocOpinion.OpinionType.draftOpinion.ordinal()), opinion.getOpinionType())) {
                        V3xOrgMember member = null;
                        try {
                            member = orgManager.getMemberById(Long.valueOf(opinion.getCreateUserId()));
                        } catch (BusinessException e) {
                            LOGGER.error("", e);
                        }
                        if (!member.getIsAdmin().booleanValue()) {
                            Comment comment = getComment(commentMap, opinion);
                            if (comment == null) {
                                LOGGER.error("文单区意见未找到对应的意见区意见，opinion.id=" + opinion.getId() + ", affairId=" + opinion.getAffairId());
                            } else {
                                if (Objects.nonNull(comment.getCreateDate())) {
                                    opinion.setCreateTime(new Timestamp(comment.getCreateDate().getTime()));
                                }
                                String attitude = getAttitude(displayConfig, opinion, comment);
                                if (Strings.isNotBlank(attitude) && !Strings.equals("report", opinion.getPolicy())) {
                                    String attitudeStr = "【" + attitude + "】";
                                    arrayList3.add(attitudeStr);
                                }
                                String content = opinion.getContent();
                                if (!FormOpinionConfig.checkBoolean(displayConfig.getComment())) {
                                    content = "";
                                }
                                arrayList3.add(content);
                                boolean newLine = displayConfig.isInscriberNewLine();
                                if (newLine) {
                                    arrayList3.add("\r\n");
                                } else if (Strings.isNotBlank(content) && (displayConfig.isShowDept() || displayConfig.isShowUnit())) {
                                    arrayList3.add("  ");
                                }
                                boolean isDisplay = true;
                                if (displayConfig.isHideInscriber()) {
                                    try {
                                        CtpAffair affair = affairManager.get(Long.valueOf(opinion.getAffairId()));
                                        if (affair != null && affair.getSubState().intValue() == SubStateEnum.col_done_stepStop.key()) {
                                            isDisplay = false;
                                        }
                                    } catch (BusinessException e2) {
                                        LOGGER.error("获取affair错误", e2);
                                    }
                                }
                                boolean hasHandWriteSignature = affairIdMapHandWriteSign != null && affairIdMapHandWriteSign.containsKey(Long.valueOf(opinion.getAffairId()));
                                String userName = getOpinionUserNameForM3(member, displayConfig, opinion, hasHandWriteSignature, edocOpinionSigns, opinion.getProxyName());
                                if (displayConfig.isShowUnit() && ((!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay)) {
                                    if (newLine) {
                                        arrayList3.add(opinion.getAccountName());
                                    } else {
                                        arrayList3.add(" ");
                                        arrayList3.add(opinion.getAccountName());
                                    }
                                }
                                if (displayConfig.isShowDept() && ((!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay)) {
                                    if (newLine && !displayConfig.isShowUnit()) {
                                        arrayList3.add(opinion.getDepartmentName());
                                    } else {
                                        arrayList3.add(" ");
                                        arrayList3.add(opinion.getDepartmentName());
                                    }
                                }
                                boolean dateNewLine = FormOpinionConfig.checkBoolean(displayConfig.getDateNewLine());
                                if (dateNewLine) {
                                    arrayList3.add(" ");
                                }
                                if (displayConfig.isShowName() && ((!displayConfig.isHideInscriber() || !hasHandWriteSignature) && isDisplay)) {
                                    arrayList3.add(" ");
                                    arrayList3.add(userName);
                                }
                                String dateStr = getDateStr(displayConfig, opinion);
                                if (Strings.isNotBlank(dateStr)) {
                                    if (dateNewLine) {
                                        arrayList3.add("\r\n");
                                        arrayList3.add(dateStr);
                                    } else {
                                        arrayList3.add(" ");
                                        arrayList3.add(dateStr);
                                    }
                                }
                                arrayList3.add("\r\n");
                                List<Attachment> tempAtts = null;
                                if (null != opinion.getPolicy() && opinion.getPolicy().equals("feedback")) {
                                    Long subOpinionId = opinion.getSubOpinionId();
                                    if (subOpinionId != null) {
                                        tempAtts = GovdocHelper.getOpinionAttachmentsNotRelationDoc(opinion.getSubEdocId().longValue(), subOpinionId.longValue());
                                    }
                                } else {
                                    tempAtts = opinion.getOpinionAttachments();
                                }
                                if (tempAtts != null && displayConfig.isShowAtt()) {
                                    StringBuilder fileName = new StringBuilder();
                                    for (Attachment att : tempAtts) {
                                        arrayList3.add("\r\n");
                                        fileName.setLength(0);
                                        fileName.append(att.getFilename());
                                        if (att.getSize().longValue() > 0 && att.getType().intValue() == 0) {
                                            fileName.append("(").append(Strings.formatFileSize(att.getSize().longValue(), true)).append(")");
                                        }
                                        arrayList3.add(fileName.toString());
                                        arrayList3.add(" ");
                                    }
                                    arrayList3.add(" ");
                                }
                                arrayList3.add("\n");
                                if (hasHandWriteSignature && (handWrite = affairIdMapHandWriteSign.get(Long.valueOf(opinion.getAffairId()))) != null) {
                                    arrayList3.add("method=writeGIF&RECORDID=" + handWrite.getSummaryId() + "&FIELDNAME=" + handWrite.getFieldName() + "&isNewImg=true&affairId=" + handWrite.getAffairId());
                                }
                                if (Strings.equals("senderOpinion", fieldName)) {
                                    arrayList2.add(opinion);
                                }
                                arrayList.add(arrayList3);
                            }
                        }
                    }
                }
            }
        }
        List<Object> result = new ArrayList<>();
        result.add(arrayList);
        result.add(arrayList2);
        return result;
    }

    private static String getDateStr(FormOpinionConfig displayConfig, EdocOpinion opinion) {
        String dateStr = "";
        if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATETIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current = opinion.getCreateTime();
                dateStr = Datetimes.format(current, ResourceUtil.getString("govdoc.date.format"));
            } else {
                dateStr = Datetimes.formatDatetimeWithoutSecond(opinion.getCreateTime());
            }
        } else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.DATE.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current2 = opinion.getCreateTime();
                dateStr = Datetimes.format(current2, ResourceUtil.getString("govdoc.date.format1"));
            } else {
                dateStr = Datetimes.formatDate(opinion.getCreateTime());
            }
        } else if (EdocOpinionDisplayEnum.OpinionDateFormatSetEnum.TIME.getValue().equals(displayConfig.getShowDateType())) {
            if (EdocOpinionDisplayEnum.OpinionDateModelSetEnum.FULL.getValue().equals(displayConfig.getShowDateModel())) {
                Date current3 = opinion.getCreateTime();
                dateStr = Datetimes.format(current3, ResourceUtil.getString("govdoc.date.format3"));
            } else {
                dateStr = Datetimes.format(opinion.getCreateTime(), " HH:mm");
            }
        }
        return dateStr;
    }

    private static String getAttitude(FormOpinionConfig displayConfig, EdocOpinion opinion, Comment comment) {
        String tempAttitude = "";
        if (opinion.getAttribute() == 1) {
            tempAttitude = "haveRead";
        } else if (opinion.getAttribute() == 2) {
            tempAttitude = "agree";
        } else if (opinion.getAttribute() == 3) {
            tempAttitude = "disagree";
        }
        String attitude = "";
        if (tempAttitude.equals(comment.getExtAtt4() == null ? "" : comment.getExtAtt4())) {
            attitude = comment.getExtAtt1I18n();
        }
        if (Strings.isNotBlank(comment.getExtAtt1())) {
            attitude = comment.getExtAtt1I18n();
        }
        if (!FormOpinionConfig.checkBoolean(displayConfig.getAttitude())) {
            attitude = "";
        }
        return attitude;
    }

    private static Comment getComment(Map<Long, List<Comment>> commentMap, EdocOpinion opinion) {
        Comment comment = null;
        List<Comment> comments = commentMap.get(Long.valueOf(opinion.getAffairId()));
        if (Strings.isNotEmpty(comments)) {
            if (comments.size() == 1) {
                comment = comments.get(0);
            } else {
                Iterator<Comment> it = comments.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    Comment tempComment = it.next();
                    if (tempComment.getCreateDate().equals(opinion.getCreateTime())) {
                        comment = tempComment;
                        break;
                    }
                }
                if (comment == null) {
                    Date beforeTwoSecond = Datetimes.addSecond(opinion.getCreateTime(), -3);
                    Date afterTwoSecond = Datetimes.addSecond(opinion.getCreateTime(), 3);
                    Iterator<Comment> it2 = comments.iterator();
                    while (true) {
                        if (!it2.hasNext()) {
                            break;
                        }
                        Comment tempComment2 = it2.next();
                        if (Datetimes.between(tempComment2.getCreateDate(), beforeTwoSecond, afterTwoSecond, false)) {
                            comment = tempComment2;
                            break;
                        }
                    }
                }
                if (comment == null) {
                    comment = comments.get(0);
                }
            }
        }
        return comment;
    }

    private static FormOpinionConfig getFormOpinionConfig(EdocSummary summary, FormOptionExtendManager formOptionExtendManager) {
        FormOptionExtend govdocFormExtend = formOptionExtendManager.findByFormId(summary.getFormAppid().longValue());
        FormOpinionConfig displayConfig = null;
        if (null != govdocFormExtend) {
            displayConfig = (FormOpinionConfig) JSONUtil.parseJSONString(govdocFormExtend.getOptionFormatSet(), FormOpinionConfig.class);
            if (!govdocFormExtend.getOptionFormatSet().contains("showAtt")) {
                displayConfig.setShowAtt(true);
            }
        }
        if (displayConfig == null) {
            displayConfig = new FormOpinionConfig();
        }
        return displayConfig;
    }
}
